[xml/sgml-commit] [linuxdoc-tools] 07/16: Fix --with-installed-entity-map regression introduced with build/install doc separation.

Agustín Martín Domingo agmartin at moszumanska.debian.org
Mon Oct 19 11:31:21 UTC 2015


This is an automated email from the git hooks/post-receive script.

agmartin pushed a commit to branch upstream
in repository linuxdoc-tools.

commit ceca9c236347635b42b63119336cda4e1cdff185
Author: Agustin Martin Domingo <agmartin at debian.org>
Date:   Tue Oct 13 20:19:28 2015 +0200

    Fix --with-installed-entity-map regression introduced with build/install doc separation.
    
      Only create and install in TMPDIR a special EntityMap.pm customized for
      doc build if --with-installed-entity-map is not passed.
    
    Signed-off-by: Agustin Martin Domingo <agmartin at debian.org>
---
 Makefile.in    |  1 +
 doc/Makedoc.sh | 25 +++++++++++++++----------
 2 files changed, 16 insertions(+), 10 deletions(-)

diff --git a/Makefile.in b/Makefile.in
index 5abc22a..46e3e04 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -85,6 +85,7 @@ ifneq ($(BUILDDOC_FORMATS),)
 	(cd doc; \
 		PREFIX=$(prefix) \
 		BUILD_ISO_ENTITIES=$(BUILD_ISO_ENTITIES) \
+		BUILD_ENTITY_MAP=$(BUILD_ENTITY_MAP) \
 	 	PKGPERL5LIB=$(CURDIR)/perl5lib \
 	 	PKGDATADIR=$(CURDIR)/lib \
 		PKGENTITYMAPDIR=$(CURDIR)/entity-map \
diff --git a/doc/Makedoc.sh b/doc/Makedoc.sh
index 5ee68e8..fc6fa2d 100644
--- a/doc/Makedoc.sh
+++ b/doc/Makedoc.sh
@@ -20,9 +20,6 @@ function abort()
 
 trap 'abort' 1 2 3 6 9 15
 
-# Set ${TMPDIR} first in perl load path (Will put Text dir there for
-# modified EntityMap.pm), then our perl5lib
-export PERL5LIB=${TMPDIR}:${PKGPERL5LIB}
 
 PERL=`which perl`
 TMPDATADIR=${TMPDIR}/linuxdoc-tools
@@ -32,13 +29,21 @@ mkdir -p ${TMPDATADIR}
 cp ../tex/*.sty ${TMPDATADIR}
 cp ../VERSION ${TMPDATADIR}
 
-# Create a modified EntityMap.pm with entity-map location in doc build
-# temporary dir. We need to properly install entity-map there.
-mkdir $TMPDIR/Text
-make -C ../entity-map install DESTDIR="$TMPDIR"
-sed < ../entity-map/EntityMap.pm.in > $TMPDIR/Text/EntityMap.pm \
-  -e 's|\@localentitymapdir\@|'${TMPDIR}'/usr/share/entity-map|g' \
-  -e 's|\@entitymapdir\@|'${TMPDIR}'/usr/share/entity-map/0.1.0|g'
+if [ "${BUILD_ENTITY_MAP}" = "true" ]; then
+    # Create a modified EntityMap.pm with entity-map location in doc
+    # build temporary dir. Need to properly install entity-map there.
+    mkdir $TMPDIR/Text
+    make -C ../entity-map install DESTDIR="$TMPDIR"
+    sed < ../entity-map/EntityMap.pm.in > $TMPDIR/Text/EntityMap.pm \
+	-e 's|\@localentitymapdir\@|'${TMPDIR}'/usr/share/entity-map|g' \
+	-e 's|\@entitymapdir\@|'${TMPDIR}'/usr/share/entity-map/0.1.0|g'
+
+    # Set ${TMPDIR} first in perl load path (Will put Text dir there
+    # for modified EntityMap.pm), then our perl5lib
+    export PERL5LIB=${TMPDIR}:${PKGPERL5LIB}
+else
+    export PERL5LIB=${PKGPERL5LIB}
+fi
 
 # Set prefix for iso-entities location and make it available if needed.
 if [ "${BUILD_ISO_ENTITIES}" = "true" ]; then

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-xml-sgml/linuxdoc-tools.git



More information about the debian-xml-sgml-commit mailing list